@@ -21,6 +21,7 @@ result = bigquery_client.query(query)
 
 ---
 """
+from time import strftime
 import google.auth.exceptions
 import logging
 from google.api_core import exceptions
@@ -90,3 +91,26 @@ class BigQuery:
             err_msg = f"Query returned no results. {e}"
             logging.error(err_msg)
             raise ValueError(err_msg)
+
+    def get_table_last_modified(self, dataset, table, to_string=False):
+        """Returns the last modified timestamp for a BigQuery table (partitioned or not). This is table-level metadata, not row-level.
+
+        Args:
+            dataset (str): BigQuery dataset ID.
+            table (str): BigQuery table ID.
+            to_string (bool, optional): If True, returns the timestamp as an ISO formatted string. Defaults to False.
+
+        Returns:
+            datetime or str: The last modified timestamp of the table in UTC.
+        """
+        if self.client is None:
+            err_msg = "BigQuery client is not initialized. Authentication failed or credentials are missing."
+            logging.error(err_msg)
+            raise ValueError(err_msg)
+
+        table_ref = self.client.dataset(dataset).table(table)
+        table = self.client.get_table(table_ref)
+        if to_string:
+            return table.modified.isoformat() if table.modified else None
+
+        return table.modified  # datetime object (UTC)
